searchNodes=[{"type":"module","title":"opentelemetry_xray_id_generator","doc":"Generate trace_id and span_id compatible with AWS X-Ray. An X-Ray trace_id consists of three values separated by hyphens. For example, the trace_id {1-5759e988-bd862e3fe1be46a994272793} includes three values: the version number 1, the time of the original request in Unix epoch time, and finally a 96-bit identifier for the trace which is globally unique. OpenTelemetry trace_ids are integers, so we combine the time and the unique id into a single 128-bit value. X-Ray (sub)segment ID is a 64-bit identifier which is unique within a single trace, and consists of 16 hexadecimal digits. https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html https://aws-otel.github.io/docs/getting-started/x-ray#configuring-the-aws-x-ray-exporter","ref":"opentelemetry_xray_id_generator.html"},{"type":"function","title":"opentelemetry_xray_id_generator.generate_span_id/0","doc":"Generates a 64 bit random integer to use as a span id.","ref":"opentelemetry_xray_id_generator.html#generate_span_id/0"},{"type":"function","title":"opentelemetry_xray_id_generator.generate_trace_id/0","doc":"Generates a 128 bit random integer to use as a trace id.","ref":"opentelemetry_xray_id_generator.html#generate_trace_id/0"},{"type":"module","title":"opentelemetry_xray_propagator","doc":"Propagator that injects and extracts context from the AWS X-Ray tracing header. When the current app is downstream from another app or the AWS load balancer, the upstream app creates the trace for the current request and sends it in the &quot;X-Amzn-Trace-Id&quot; HTTP header. The header includes the trace id and optional information about the parent span and sampling. Similarly, when the current app makes calls to downstream services, it sets the header to pass the current trace context. NOTE: Amazon assumes that spans are not sampled by default. If you want your traces to be sampled, make sure that you turn it on. https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-tracingheader","ref":"opentelemetry_xray_propagator.html"},{"type":"function","title":"opentelemetry_xray_propagator.extract/5","doc":"Extract context from carrier.","ref":"opentelemetry_xray_propagator.html#extract/5"},{"type":"function","title":"opentelemetry_xray_propagator.fields/1","doc":"Return list of the keys the propagator sets with inject .","ref":"opentelemetry_xray_propagator.html#fields/1"},{"type":"function","title":"opentelemetry_xray_propagator.inject/4","doc":"Inject context into carrier.","ref":"opentelemetry_xray_propagator.html#inject/4"},{"type":"extras","title":"Overview","doc":"opentelemetry_xray OpenTelemetry AWS X-Ray support for Erlang/Elixir. This library includes two modules: An id generator that creates X-Ray-compatible trace_id and span_id . It implements the otel_id_generator protocol in the Erlang SDK. A propagator that reads and writes AWS X-Ray trace context headers. It implements the otel_propagator_text_map protocol in the Erlang SDK. It assumes that you are using the AWS Distro for OpenTelemetry Collector , a version of the OpenTelemetry Collector which has support for AWS services such as X-Ray. It accepts standard OpenTelemetry traces, converts them to X-Ray format, and sends them to AWS. You can run the collector as a sidecar container in an ECS task or as a daemon on an EC2 instance. In AWS X-Ray, the trace_id is a 128-bit value. The first 32 bits are a Unix time_t and the rest are a 96-bit random number. If you use the default trace_id , then X-Ray will reject your traces. This library generates ids that are compatible with X-Ray. If your app is running behind an AWS Application Load Balancer, then the ALB will pass a trace in the X-Amzn-Trace-Id header. This library includes a propagator which reads the trace id from this header and uses it within your app. It can then pass the same trace id to downstream apps via the header. Links: Propagator: https://opentelemetry.io/docs/specs/otel/context/api-propagators/ https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-tracingheader https://aws-otel.github.io/docs/getting-started/x-ray#configuring-the-aws-x-ray-exporter https://davelucia.com/blog/observing-elixir-with-lightstep https://opentelemetry.io/docs/instrumentation/erlang/getting-started/","ref":"readme.html"},{"type":"extras","title":"Overview - Installation","doc":"Erlang: Add opentelemetry_xray to the list of dependencies in rebar.config : { deps , [ opentelemetry_xray ] } . Elixir: Add logger_formatter_json to the list of dependencies in mix.exs : def deps do [ { :opentelemetry_xray , &quot;~&gt; 0.7&quot; } , ] end","ref":"readme.html#installation"},{"type":"extras","title":"Overview - Configuration","doc":"In config/config.exs or config/prod.exs , configure opentelemetry to use this library: config :opentelemetry , id_generator : :opentelemetry_xray_id_generator , propagators : [ :opentelemetry_xray_propagator , :baggage ] See phoenix_container_example for a complete Elixir Phoenix app that uses this library.","ref":"readme.html#configuration"},{"type":"extras","title":"Changelog","doc":"All notable changes to this project will be documented in this file. The format is based on Keep a Changelog , and this project adheres to Semantic Versioning .","ref":"changelog.html"},{"type":"extras","title":"Changelog - [0.1.0] - 2023-10-23","doc":"Added Initial version","ref":"changelog.html#0-1-0-2023-10-23"},{"type":"extras","title":"Changelog - [0.1.1] - 2023-10-23","doc":"Added Updated docs","ref":"changelog.html#0-1-1-2023-10-23"},{"type":"extras","title":"Changelog - [0.7.0] - 2023-10-30","doc":"Added Updated docs","ref":"changelog.html#0-7-0-2023-10-30"},{"type":"extras","title":"License (Apache 2.0)","doc":"Version 2.0, January 2004 http://www.apache.org/licenses/ TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION","ref":"license.html"},{"type":"extras","title":"License (Apache 2.0) - 1. Definitions.","doc":"&quot;License&quot; shall mean the terms and conditions for use, reproduction, and distribution as defined by Sections 1 through 9 of this document. &quot;Licensor&quot; shall mean the copyright owner or entity authorized by the copyright owner that is granting the License. &quot;Legal Entity&quot; shall mean the union of the acting entity and all other entities that control, are controlled by, or are under common control with that entity. For the purposes of this definition, &quot;control&quot; means (i) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (ii) ownership of fifty percent (50%) or more of the outstanding shares, or (iii) beneficial ownership of such entity. &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity exercising permissions granted by this License. &quot;Source&quot; form shall mean the preferred form for making modifications, including but not limited to software source code, documentation source, and configuration files. &quot;Object&quot; form shall mean any form resulting from mechanical transformation or translation of a Source form, including but not limited to compiled object code, generated documentation, and conversions to other media types. &quot;Work&quot; shall mean the work of authorship, whether in Source or Object form, made available under the License, as indicated by a copyright notice that is included in or attached to the work (an example is provided in the Appendix below). &quot;Derivative Works&quot; shall mean any work, whether in Source or Object form, that is based on (or derived from) the Work and for which the editorial revisions, annotations, elaborations, or other modifications represent, as a whole, an original work of authorship. For the purposes of this License, Derivative Works shall not include works that remain separable from, or merely link (or bind by name) to the interfaces of, the Work and Derivative Works thereof. &quot;Contribution&quot; shall mean any work of authorship, including the original version of the Work and any modifications or additions to that Work or Derivative Works thereof, that is intentionally submitted to Licensor for inclusion in the Work by the copyright owner or by an individual or Legal Entity authorized to submit on behalf of the copyright owner. For the purposes of this definition, &quot;submitted&quot; means any form of electronic, verbal, or written communication sent to the Licensor or its representatives, including but not limited to communication on electronic mailing lists, source code control systems, and issue tracking systems that are managed by, or on behalf of, the Licensor for the purpose of discussing and improving the Work, but excluding communication that is conspicuously marked or otherwise designated in writing by the copyright owner as &quot;Not a Contribution.&quot; &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity on behalf of whom a Contribution has been received by Licensor and subsequently incorporated within the Work.","ref":"license.html#1-definitions"},{"type":"extras","title":"License (Apache 2.0) - 2. Grant of Copyright License.","doc":"Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright license to reproduce, prepare Derivative Works of, publicly display, publicly perform, sublicense, and distribute the Work and such Derivative Works in Source or Object form.","ref":"license.html#2-grant-of-copyright-license"},{"type":"extras","title":"License (Apache 2.0) - 3. Grant of Patent License.","doc":"Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable (except as stated in this section) patent license to make, have made, use, offer to sell, sell, import, and otherwise transfer the Work, where such license applies only to those patent claims licensable by such Contributor that are necessarily infringed by their Contribution(s) alone or by combination of their Contribution(s) with the Work to which such Contribution(s) was submitted. If You institute patent litigation against any entity (including a cross-claim or counterclaim in a lawsuit) alleging that the Work or a Contribution incorporated within the Work constitutes direct or contributory patent infringement, then any patent licenses granted to You under this License for that Work shall terminate as of the date such litigation is filed.","ref":"license.html#3-grant-of-patent-license"},{"type":"extras","title":"License (Apache 2.0) - 4. Redistribution.","doc":"You may reproduce and distribute copies of the Work or Derivative Works thereof in any medium, with or without modifications, and in Source or Object form, provided that You meet the following conditions: You must give any other recipients of the Work or Derivative Works a copy of this License; and You must cause any modified files to carry prominent notices stating that You changed the files; and You must retain, in the Source form of any Derivative Works that You distribute, all copyright, patent, trademark, and attribution notices from the Source form of the Work, excluding those notices that do not pertain to any part of the Derivative Works; and If the Work includes a &quot;NOTICE&quot; text file as part of its distribution, then any Derivative Works that You distribute must include a readable copy of the attribution notices contained within such NOTICE file, excluding those notices that do not pertain to any part of the Derivative Works, in at least one of the following places: within a NOTICE text file distributed as part of the Derivative Works; within the Source form or documentation, if provided along with the Derivative Works; or, within a display generated by the Derivative Works, if and wherever such third-party notices normally appear. The contents of the NOTICE file are for informational purposes only and do not modify the License. You may add Your own attribution notices within Derivative Works that You distribute, alongside or as an addendum to the NOTICE text from the Work, provided that such additional attribution notices cannot be construed as modifying the License. You may add Your own copyright statement to Your modifications and may provide additional or different license terms and conditions for use, reproduction, or distribution of Your modifications, or for any such Derivative Works as a whole, provided Your use, reproduction, and distribution of the Work otherwise complies with the conditions stated in this License.","ref":"license.html#4-redistribution"},{"type":"extras","title":"License (Apache 2.0) - 5. Submission of Contributions.","doc":"Unless You explicitly state otherwise, any Contribution intentionally submitted for inclusion in the Work by You to the Licensor shall be under the terms and conditions of this License, without any additional terms or conditions. Notwithstanding the above, nothing herein shall supersede or modify the terms of any separate license agreement you may have executed with Licensor regarding such Contributions.","ref":"license.html#5-submission-of-contributions"},{"type":"extras","title":"License (Apache 2.0) - 6. Trademarks.","doc":"This License does not grant permission to use the trade names, trademarks, service marks, or product names of the Licensor, except as required for reasonable and customary use in describing the origin of the Work and reproducing the content of the NOTICE file.","ref":"license.html#6-trademarks"},{"type":"extras","title":"License (Apache 2.0) - 7. Disclaimer of Warranty.","doc":"Unless required by applicable law or agreed to in writing, Licensor provides the Work (and each Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied, including, without limitation, any warranties or conditions of TITLE, NON- INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are solely responsible for determining the appropriateness of using or redistributing the Work and assume any risks associated with Your exercise of permissions under this License.","ref":"license.html#7-disclaimer-of-warranty"},{"type":"extras","title":"License (Apache 2.0) - 8. Limitation of Liability.","doc":"In no event and under no legal theory, whether in tort (including negligence), contract, or otherwise, unless required by applicable law (such as deliberate and grossly negligent acts) or agreed to in writing, shall any Contributor be liable to You for damages, including any direct, indirect, special, incidental, or consequential damages of any character arising as a result of this License or out of the use or inability to use the Work (including but not limited to damages for loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses), even if such Contributor has been advised of the possibility of such damages.","ref":"license.html#8-limitation-of-liability"},{"type":"extras","title":"License (Apache 2.0) - 9. Accepting Warranty or Additional Liability.","doc":"While redistributing the Work or Derivative Works thereof, You may choose to offer, and charge a fee for, acceptance of support, warranty, indemnity, or other liability obligations and/or rights consistent with this License. However, in accepting such obligations, You may act only on Your own behalf and on Your sole responsibility, not on behalf of any other Contributor, and only if You agree to indemnify, defend, and hold each Contributor harmless for any liability incurred by, or claims asserted against, such Contributor by reason of your accepting any such warranty or additional liability. END OF TERMS AND CONDITIONS Copyright 2023, Jake Morrison jake@cogini.com . Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"license.html#9-accepting-warranty-or-additional-liability"},{"type":"extras","title":"Contributing","doc":"Build: rebar3 compile Test: rebar3 ct Format code: rebar3 steamroll Generate docs: rebar3 ex_docs Publish: rebar3 hex user auth rebar3 hex build rebar3 hex publish This project uses the Contributor Covenant version 2.1. Check CODE_OF_CONDUCT.md for more information.","ref":"contributing.html"},{"type":"extras","title":"Code of Conduct","doc":"","ref":"code_of_conduct.html"},{"type":"extras","title":"Code of Conduct - Our Pledge","doc":"We as members, contributors, and leaders pledge to make participation in our community a harassment-free experience for everyone, regardless of age, body size, visible or invisible disability, ethnicity, sex characteristics, gender identity and expression, level of experience, education, socio-economic status, nationality, personal appearance, race, caste, color, religion, or sexual identity and orientation. We pledge to act and interact in ways that contribute to an open, welcoming, diverse, inclusive, and healthy community.","ref":"code_of_conduct.html#our-pledge"},{"type":"extras","title":"Code of Conduct - Our Standards","doc":"Examples of behavior that contributes to a positive environment for our community include: Demonstrating empathy and kindness toward other people Being respectful of differing opinions, viewpoints, and experiences Giving and gracefully accepting constructive feedback Accepting responsibility and apologizing to those affected by our mistakes, and learning from the experience Focusing on what is best not just for us as individuals, but for the overall community Examples of unacceptable behavior include: The use of sexualized language or imagery, and sexual attention or advances of any kind Trolling, insulting or derogatory comments, and personal or political attacks Public or private harassment Publishing others' private information, such as a physical or email address, without their explicit permission Other conduct which could reasonably be considered inappropriate in a professional setting","ref":"code_of_conduct.html#our-standards"},{"type":"extras","title":"Code of Conduct - Enforcement Responsibilities","doc":"Community leaders are responsible for clarifying and enforcing our standards of acceptable behavior and will take appropriate and fair corrective action in response to any behavior that they deem inappropriate, threatening, offensive, or harmful. Community leaders have the right and responsibility to remove, edit, or reject comments, commits, code, wiki edits, issues, and other contributions that are not aligned to this Code of Conduct, and will communicate reasons for moderation decisions when appropriate.","ref":"code_of_conduct.html#enforcement-responsibilities"},{"type":"extras","title":"Code of Conduct - Scope","doc":"This Code of Conduct applies within all community spaces, and also applies when an individual is officially representing the community in public spaces. Examples of representing our community include using an official e-mail address, posting via an official social media account, or acting as an appointed representative at an online or offline event.","ref":"code_of_conduct.html#scope"},{"type":"extras","title":"Code of Conduct - Enforcement","doc":"Instances of abusive, harassing, or otherwise unacceptable behavior may be reported to the community leaders responsible for enforcement at engineering@therealreal.com. All complaints will be reviewed and investigated promptly and fairly. All community leaders are obligated to respect the privacy and security of the reporter of any incident.","ref":"code_of_conduct.html#enforcement"},{"type":"extras","title":"Code of Conduct - Enforcement Guidelines","doc":"Community leaders will follow these Community Impact Guidelines in determining the consequences for any action they deem in violation of this Code of Conduct: 1. Correction Community Impact : Use of inappropriate language or other behavior deemed unprofessional or unwelcome in the community. Consequence : A private, written warning from community leaders, providing clarity around the nature of the violation and an explanation of why the behavior was inappropriate. A public apology may be requested. 2. Warning Community Impact : A violation through a single incident or series of actions. Consequence : A warning with consequences for continued behavior. No interaction with the people involved, including unsolicited interaction with those enforcing the Code of Conduct, for a specified period of time. This includes avoiding interactions in community spaces as well as external channels like social media. Violating these terms may lead to a temporary or permanent ban. 3. Temporary Ban Community Impact : A serious violation of community standards, including sustained inappropriate behavior. Consequence : A temporary ban from any sort of interaction or public communication with the community for a specified period of time. No public or private interaction with the people involved, including unsolicited interaction with those enforcing the Code of Conduct, is allowed during this period. Violating these terms may lead to a permanent ban. 4. Permanent Ban Community Impact : Demonstrating a pattern of violation of community standards, including sustained inappropriate behavior, harassment of an individual, or aggression toward or disparagement of classes of individuals. Consequence : A permanent ban from any sort of public interaction within the community.","ref":"code_of_conduct.html#enforcement-guidelines"},{"type":"extras","title":"Code of Conduct - Attribution","doc":"This Code of Conduct is adapted from the Contributor Covenant , version 2.1, available at https://www.contributor-covenant.org/version/2/1/code_of_conduct.html . Community Impact Guidelines were inspired by Mozilla's code of conduct enforcement ladder . For answers to common questions about this code of conduct, see the FAQ at https://www.contributor-covenant.org/faq . Translations are available at https://www.contributor-covenant.org/translations .","ref":"code_of_conduct.html#attribution"}]